==> lodash-3.8.0-amd.jar: META-INF/resources/webjars/lodash/3.8.0-amd/math/min.js <==
define(['../internal/arrayMin', '../internal/createExtremum'], function(arrayMin, createExtremum) {

  /**
   * Gets the minimum value of `collection`. If `collection` is empty or falsey
   * `Infinity` is returned. If an iteratee function is provided it is invoked
   * for each value in `collection` to generate the criterion by which the value
   * is ranked. The `iteratee` is bound to `thisArg` and invoked with three
   * arguments: (value, index, collection).
   *
   * If a property name is provided for `iteratee` the created `_.property`
   * style callback returns the property value of the given element.
   *
   * If a value is also provided for `thisArg` the created `_.matchesProperty`
   * style callback returns `true` for elements that have a matching property
   * value, else `false`.
   *
   * If an object is provided for `iteratee` the created `_.matches` style
   * callback returns `true` for elements that have the properties of the given
   * object, else `false`.
   *
   * @static
   * @memberOf _
   * @category Math
   * @param {Array|Object|string} collection The collection to iterate over.
   * @param {Function|Object|string} [iteratee] The function invoked per iteration.
   * @param {*} [thisArg] The `this` binding of `iteratee`.
   * @returns {*} Returns the minimum value.
   * @example
   *
   * _.min([4, 2, 8, 6]);
   * // => 2
   *
   * _.min([]);
   * // => Infinity
   *
   * var users = [
   *   { 'user': 'barney', 'age': 36 },
   *   { 'user': 'fred',   'age': 40 }
   * ];
   *
   * _.min(users, function(chr) {
   *   return chr.age;
   * });
   * // => { 'user': 'barney', 'age': 36 }
   *
   * // using the `_.property` callback shorthand
   * _.min(users, 'age');
   * // => { 'user': 'barney', 'age': 36 }
   */
  var min = createExtremum(arrayMin, true);

  return min;
});

==> lodash-3.9.3-amd.jar: META-INF/resources/webjars/lodash/3.9.3-amd/math/min.js <==
define(['../internal/createExtremum', '../lang/lt'], function(createExtremum, lt) {

  /** Used as references for `-Infinity` and `Infinity`. */
  var POSITIVE_INFINITY = Number.POSITIVE_INFINITY;

  /**
   * Gets the minimum value of `collection`. If `collection` is empty or falsey
   * `Infinity` is returned. If an iteratee function is provided it is invoked
   * for each value in `collection` to generate the criterion by which the value
   * is ranked. The `iteratee` is bound to `thisArg` and invoked with three
   * arguments: (value, index, collection).
   *
   * If a property name is provided for `iteratee` the created `_.property`
   * style callback returns the property value of the given element.
   *
   * If a value is also provided for `thisArg` the created `_.matchesProperty`
   * style callback returns `true` for elements that have a matching property
   * value, else `false`.
   *
   * If an object is provided for `iteratee` the created `_.matches` style
   * callback returns `true` for elements that have the properties of the given
   * object, else `false`.
   *
   * @static
   * @memberOf _
   * @category Math
   * @param {Array|Object|string} collection The collection to iterate over.
   * @param {Function|Object|string} [iteratee] The function invoked per iteration.
   * @param {*} [thisArg] The `this` binding of `iteratee`.
   * @returns {*} Returns the minimum value.
   * @example
   *
   * _.min([4, 2, 8, 6]);
   * // => 2
   *
   * _.min([]);
   * // => Infinity
   *
   * var users = [
   *   { 'user': 'barney', 'age': 36 },
   *   { 'user': 'fred',   'age': 40 }
   * ];
   *
   * _.min(users, function(chr) {
   *   return chr.age;
   * });
   * // => { 'user': 'barney', 'age': 36 }
   *
   * // using the `_.property` callback shorthand
   * _.min(users, 'age');
   * // => { 'user': 'barney', 'age': 36 }
   */
  var min = createExtremum(lt, POSITIVE_INFINITY);

  return min;
});
